@@ -125,12 +125,11 @@ class CmdUploadDeb(CmdUpload):
         package_fold = pkg_layout.package(pref)
         conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, package_fold)
         
+        assert (not conanfile.apt_user), "apt_user is not defined or empty in conanfile.py."
+        assert (not conanfile.apt_server), "apt_server is not defined or empty in conanfile.py."
+        
         deb_folder = pkg_layout.deb(pref)
         deb_file = os.path.join(deb_folder, conanfile.name + "_" + conanfile.version + ".deb")
-
-        if conanfile.apt_server == "":
-            self._output.error("apt_server is not defined in conanfile.")
-            return pref
         
         msg = "\rUploading %s to remote '%s'" % (str(pref.ref), conanfile.apt_server)
         self._output.info(left_justify_message(msg))
