@@ -101,15 +101,10 @@ def _create_deb_file(conanfile):
     #### generate package in build
     mkdir(debian_folder)
     mkdir(app_folder)
-        
-    ## add changelog file
-    changelog_file = debian_folder + "/changelog"
-    if os.path.exists(changelog_file):
-        conanfile.run("rm " + changelog_file)
-    add_changelog_cmd = "echo " + conanfile.changelog + " >> " + changelog_file
-    conanfile.run(add_changelog_cmd)
     
     ## add control file
+    assert (not conanfile.deb_control), "deb_control is not defined or empty in conanfile.py."
+    
     control_file = debian_folder + "/control"
     if os.path.exists(control_file):
         conanfile.run("rm " + control_file)
@@ -120,8 +115,17 @@ def _create_deb_file(conanfile):
                         "echo Description: " + conanfile.deb_control["Description"] + " >> " + control_file + " && "  \
                         "echo 'Depends: " + conanfile.deb_control["Depends"] + "' >> " + control_file + " && "  \
                         "echo Essential: " + conanfile.deb_control["Essential"] + " >> " + control_file + " "
-    conanfile.run(add_control_cmd)  
-        
+    conanfile.run(add_control_cmd)
+
+    ## add changelog file
+    assert (not conanfile.deb_changelog), "deb_changelog is not defined or empty in conanfile.py."
+    
+    changelog_file = debian_folder + "/changelog"
+    if os.path.exists(changelog_file):
+        conanfile.run("rm " + changelog_file)
+    add_changelog_cmd = "echo " + conanfile.deb_changelog + " >> " + changelog_file
+    conanfile.run(add_changelog_cmd)
+
     ## add lib | bin
     add_lib_cmd = "cp -r lib " + app_folder + "/lib "
     if os.path.exists("lib"):
@@ -141,7 +145,8 @@ def _create_deb_file(conanfile):
     
     ## clean package folder
     if os.path.exists(deb_folder):
-            conanfile.run("rm -rf " + deb_folder)
+        conanfile.run("rm -rf " + deb_folder)
+        output.info("clean deb_folder in package.")
     else:
         msg = "deb_folde '%s' is not existed. \
                 Check deb_folder is generated correctly." % (deb_folder)
@@ -149,6 +154,7 @@ def _create_deb_file(conanfile):
 
     if os.path.exists(deb_file):
         conanfile.run("rm -rf " + deb_file)
+        output.info("clean deb_file in package.")
     else:
         msg = "deb_file '%s' is not existed. \
                 Check deb_file is generated correctly." % (deb_file)
